@@ -1,14 +1,17 @@
 package GraphViz;
 
+use 5.006;
 use strict;
 use warnings;
-use vars qw($AUTOLOAD $VERSION);
+our $AUTOLOAD;
 
 use Carp;
 use Config;
 use IPC::Run qw(run binary);
 
-our $VERSION = '2.10';
+our $VERSION = '2.18';
+
+=pod
 
 =head1 NAME
 
@@ -35,11 +38,47 @@ GraphViz - Interface to AT&T's GraphViz. Deprecated. See GraphViz2
 
 This module provides an interface to layout and image generation of directed
 and undirected graphs in a variety of formats (PostScript, PNG, etc.) using the
-"dot", "neato", "twopi", "circo" and "fdp"  programs from the GraphViz project
+"dot", "neato", "twopi", "circo" and "fdp"  programs from the Graphviz project
 (http://www.graphviz.org/ or http://www.research.att.com/sw/tools/graphviz/).
 
 GraphViz is deprecated in favour of L<GraphViz2>.
 
+=head1 Installation
+
+Of course you need to install AT&T's Graphviz before using this module.
+See L<http://www.graphviz.org/Download.php>.
+
+You are strongly advised to download the stable version of Graphviz, because the
+development snapshots (click on 'Source code'), are sometimes non-functional.
+
+Install L<GraphViz> as you would for any C<Perl> module:
+
+Run:
+
+	cpanm GraphViz
+
+	Note: cpanm ships in App::cpanminus. See also App::perlbrew.
+
+or run:
+
+	sudo cpan GraphViz
+
+or unpack the distro, and then either:
+
+	perl Build.PL
+	./Build
+	./Build test
+	sudo ./Build install
+
+or:
+
+	perl Makefile.PL
+	make (or dmake or nmake)
+	make test
+	make install
+
+=head1 Overview
+
 =head2 Modules in this distro
 
 =over 4
@@ -243,7 +282,6 @@ that overlap.  (From GraphViz documentation:)
 
 Determines if and how node overlaps should be removed.
 
-
 =over
 
 =item true
@@ -737,7 +775,7 @@ labelfontname, labelfontsize are also allowed
 
 sets the distance from the edge / port to the label. Also labelangle
 
-=item decorateP
+=item decorate
 
 if set, draws a line from the edge to the label
 
@@ -955,6 +993,12 @@ image map format file.
 
   print $g->as_imap;
 
+=item as_vdx
+
+Returns a string which contains a VDX-format (Microsoft Visio) file.
+
+  print $g->as_vdx;
+
 =item as_vrml
 
 Returns a string which contains a layed-out VRML-format file.
@@ -1021,7 +1065,7 @@ sub AUTOLOAD {
     }
 
     if ( $name
-        =~ /^as_(ps|hpgl|pcl|mif|pic|gd|gd2|gif|jpeg|png|wbmp|cmapx?|ismap|imap|vrml|vtx|mp|fig|svgz?|dot|canon|plain)$/
+        =~ /^as_(ps|hpgl|pcl|mif|pic|gd|gd2|gif|jpeg|png|wbmp|cmapx?|ismap|imap|vdx|vrml|vtx|mp|fig|svgz?|dot|canon|plain)$/
         )
     {
         my $data = $self->_as_generic( '-T' . $1, $self->_as_debug, $output );
@@ -1277,13 +1321,16 @@ sub _attributes {
         next if $key =~ /^_/;
         next if $key =~ /^(to|from|name|cluster|from_port|to_port)$/;
 
-        my $value = $thing->{$key};
-        $value =~ s|"|\"|g;
-        $value = '"' . $value . '"'
-            unless ( $key eq 'label' && $value =~ /^<</ );
-        $value =~ s|\n|\\n|g;
+        my $value = $thing->{$key} || '';
+
+		if ( $key ne 'label' || $value !~ /^<</ )
+		{
+	        $value =~ s|"|\\"|g;
+   		    $value = '"' . $value . '"'
+		}
+       	$value =~ s|\n|\\n|g;
+        $value = '""' if ( ($value eq '') && ($value ne '""') );
 
-        $value = '""' if not defined $value;
         push @attributes, "$key=$value";
     }
 
@@ -1294,6 +1341,32 @@ sub _attributes {
     }
 }
 
+=head1 FAQ
+
+=head2 Why do I get error messages like the following?
+
+	Error: <stdin>:1: syntax error near line 1
+	context: digraph >>>  Graph <<<  {
+
+Graphviz reserves some words as keywords, meaning they can't be used as an ID, e.g. for the name of the graph.
+So, don't do this:
+
+	strict graph graph{...}
+	strict graph Graph{...}
+	strict graph strict{...}
+	etc...
+
+Likewise for non-strict graphs, and digraphs. You can however add double-quotes around such reserved words:
+
+	strict graph "graph"{...}
+
+Even better, use a more meaningful name for your graph...
+
+The keywords are: node, edge, graph, digraph, subgraph and strict. Compass points are not keywords.
+
+See L<keywords|http://www.graphviz.org/content/dot-language> in the discussion of the syntax of DOT
+for details.
+
 =head1 NOTES
 
 Older versions of GraphViz used a slightly different syntax for node
@@ -1307,7 +1380,7 @@ GraphViz is deprecated in favour of L<GraphViz2>.
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 AUTHOR
 
