@@ -3,11 +3,10 @@ package GraphViz::Small;
 use strict;
 use warnings;
 use GraphViz;
-use vars qw($VERSION @ISA);
 
-@ISA = qw(GraphViz);
+our @ISA = qw(GraphViz);
 
-our $VERSION = '2.14';
+our $VERSION = '2.18';
 
 =head1 NAME
 
